aboutsummaryrefslogtreecommitdiffstats
path: root/lib/bundler/vendor/thor/shell/basic.rb
diff options
context:
space:
mode:
Diffstat (limited to 'lib/bundler/vendor/thor/shell/basic.rb')
-rw-r--r--lib/bundler/vendor/thor/shell/basic.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/bundler/vendor/thor/shell/basic.rb b/lib/bundler/vendor/thor/shell/basic.rb
index c8411d3d..a7c464ad 100644
--- a/lib/bundler/vendor/thor/shell/basic.rb
+++ b/lib/bundler/vendor/thor/shell/basic.rb
@@ -5,10 +5,10 @@ class Thor
class Basic
attr_accessor :base, :padding
# Initialize base and padding to nil.
#
def initialize #:nodoc:
- @base, @padding = nil, 0
+ @base, @mute, @padding = nil, false, 0
end
# Mute everything that's inside given block
@@ -5,10 +5,10 @@ class Thor
class Basic
attr_accessor :base, :padding
- # Initialize base and padding to nil.
+ # Initialize base, mute and padding to nil.
#
def initialize #:nodoc: